@@ -17,23 +17,29 @@
 
 package Fedora::App::MaintainerTools::Types;
 
-use MooseX::Types -declare => [ 'CPBackend', 'CPModule' ];
+use MooseX::Types -declare => [ qw{ CPBackend CPModule SpecData } ];
 use MooseX::Types::Moose ':all';
 
-use namespace::clean -except => [ 'meta', 'CPBackend', 'CPModule' ];
+use namespace::clean -except => [ 'meta', 'CPBackend', 'CPModule', 'SpecData' ];
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 subtype CPBackend,
     as Object,
     where   { $_->isa('CPANPLUS::Backend')   },
-    message { 'Object isa CPANPLUS::Backend' },
+    message { 'Object !isa CPANPLUS::Backend' },
     ;
 
 subtype CPModule,
     as Object,
     where { $_->isa('CPANPLUS::Module')     },
-    message { 'Object isa CPANPLUS::Module' },
+    message { 'Object !isa CPANPLUS::Module' },
+    ;
+
+subtype SpecData,
+    as Object,
+    where   { $_->isa('Fedora::App::MaintainerTools::SpecData')    },
+    message { 'Object !isa Fedora::App::MaintainerTools::SpecData' },
     ;
 
 __PACKAGE__->meta->make_immutable;
